package com.sun.corba.se.impl.ior;

import com.sun.corba.se.spi.protocol.CorbaServerRequestDispatcher;
import com.sun.corba.se.spi.orb.ORBVersionFactory;
import com.sun.corba.se.spi.orb.ORBVersion;
import com.sun.corba.se.spi.ior.ObjectAdapterId;
import org.omg.CORBA_2_3.portable.OutputStream;
import com.sun.corba.se.spi.ior.ObjectId;
import org.omg.CORBA.OctetSeqHolder;
import com.sun.corba.se.impl.encoding.CDRInputStream;
import org.omg.CORBA_2_3.portable.InputStream;
import com.sun.corba.se.impl.logging.IORSystemException;
import com.sun.corba.se.spi.orb.ORB;
import com.sun.corba.se.spi.ior.ObjectKeyTemplate;

public class WireObjectKeyTemplate implements ObjectKeyTemplate
{
    private ORB orb;
    private IORSystemException wrapper;
    
    @Override
    public boolean equals(Object o) {
        return o != null && o instanceof WireObjectKeyTemplate;
    }
    
    @Override
    public int hashCode() {
        return 53;
    }
    
    private byte[] getId(InputStream inputStream) {
        CDRInputStream cdrInputStream = (CDRInputStream)inputStream;
        int bufferLength = cdrInputStream.getBufferLength();
        byte[] array = new byte[bufferLength];
        cdrInputStream.read_octet_array(array, 0, bufferLength);
        return array;
    }
    
    public WireObjectKeyTemplate(ORB orb) {
        this.initORB(orb);
    }
    
    public WireObjectKeyTemplate(InputStream inputStream, OctetSeqHolder octetSeqHolder) {
        octetSeqHolder.value = this.getId(inputStream);
        this.initORB((ORB)(ORB)inputStream.orb());
    }
    
    private void initORB(ORB orb) {
        this.orb = orb;
        this.wrapper = IORSystemException.get(orb, "oa.ior");
    }
    
    public void write(ObjectId objectId, OutputStream outputStream) {
        byte[] id = objectId.getId();
        outputStream.write_octet_array(id, 0, id.length);
    }
    
    public void write(OutputStream outputStream) {
    }
    
    public int getSubcontractId() {
        return 2;
    }
    
    public int getServerId() {
        return -1;
    }
    
    public String getORBId() {
        throw this.wrapper.orbIdNotAvailable();
    }
    
    public ObjectAdapterId getObjectAdapterId() {
        throw this.wrapper.objectAdapterIdNotAvailable();
    }
    
    public byte[] getAdapterId() {
        throw this.wrapper.adapterIdNotAvailable();
    }
    
    public ORBVersion getORBVersion() {
        return ORBVersionFactory.getFOREIGN();
    }
    
    public CorbaServerRequestDispatcher getServerRequestDispatcher(ORB orb, ObjectId objectId) {
        return orb.getRequestDispatcherRegistry().getServerRequestDispatcher(new String(objectId.getId()));
    }
}
